==> symbol-processing-aa-embeddable-2.2.0-2.0.2-sources.jar: org/jetbrains/kotlin/fir/analysis/js/checkers/JsExpressionCheckers.kt <==
/*
 * Copyright 2010-2021 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.fir.analysis.js.checkers

import ksp.org.jetbrains.kotlin.fir.analysis.checkers.expression.*
import ksp.org.jetbrains.kotlin.fir.analysis.js.checkers.expression.*
import ksp.org.jetbrains.kotlin.fir.analysis.web.common.checkers.expression.FirJsCodeConstantArgumentChecker
import ksp.org.jetbrains.kotlin.fir.analysis.web.common.checkers.expression.FirJsQualifierChecker

object JsExpressionCheckers : ExpressionCheckers() {
    override val annotationCallCheckers: Set<FirAnnotationCallChecker>
        get() = setOf(
            FirJsQualifierChecker,
        )

    override val basicExpressionCheckers: Set<FirBasicExpressionChecker>
        get() = setOf(
            FirJsDefinedExternallyCallChecker,
            FirJsNativeRttiChecker,
            FirJsReflectionAPICallChecker
        )

    override val functionCallCheckers: Set<FirFunctionCallChecker>
        get() = setOf(
            FirJsCodeConstantArgumentChecker,
            FirJsReifiedExternalChecker
        )

    override val callCheckers: Set<FirCallChecker>
        get() = setOf(
            FirJsExternalArgumentCallChecker
        )

    override val getClassCallCheckers: Set<FirGetClassCallChecker>
        get() = setOf(
            FirJsModuleGetClassCallChecker
        )

    override val qualifiedAccessExpressionCheckers: Set<FirQualifiedAccessExpressionChecker>
        get() = setOf(
            FirJsModuleQualifiedAccessChecker,
            FirJsDynamicCallChecker
        )
}

==> symbol-processing-aa-embeddable-2.3.3-sources.jar: org/jetbrains/kotlin/fir/analysis/js/checkers/JsExpressionCheckers.kt <==
/*
 * Copyright 2010-2021 JetBrains s.r.o. and Kotlin Programming Language contributors.
 * Use of this source code is governed by the Apache 2.0 license that can be found in the license/LICENSE.txt file.
 */

package ksp.org.jetbrains.kotlin.fir.analysis.js.checkers

import ksp.org.jetbrains.kotlin.fir.analysis.checkers.expression.*
import ksp.org.jetbrains.kotlin.fir.analysis.js.checkers.expression.*
import ksp.org.jetbrains.kotlin.fir.analysis.web.common.checkers.expression.FirJsCodeConstantArgumentChecker
import ksp.org.jetbrains.kotlin.fir.analysis.web.common.checkers.expression.FirJsQualifierChecker
import ksp.org.jetbrains.kotlin.fir.analysis.web.common.checkers.expression.FirWebReflectionAPICallChecker

object JsExpressionCheckers : ExpressionCheckers() {
    override val annotationCallCheckers: Set<FirAnnotationCallChecker>
        get() = setOf(
            FirJsQualifierChecker,
        )

    override val basicExpressionCheckers: Set<FirBasicExpressionChecker>
        get() = setOf(
            FirJsDefinedExternallyCallChecker,
            FirJsNativeRttiChecker,
            FirWebReflectionAPICallChecker(isWasm = false),
        )

    override val functionCallCheckers: Set<FirFunctionCallChecker>
        get() = setOf(
            FirJsCodeConstantArgumentChecker,
            FirJsReifiedExternalChecker
        )

    override val callCheckers: Set<FirCallChecker>
        get() = setOf(
            FirJsExternalArgumentCallChecker
        )

    override val getClassCallCheckers: Set<FirGetClassCallChecker>
        get() = setOf(
            FirJsModuleGetClassCallChecker
        )

    override val qualifiedAccessExpressionCheckers: Set<FirQualifiedAccessExpressionChecker>
        get() = setOf(
            FirJsModuleQualifiedAccessChecker,
            FirJsDynamicCallChecker
        )
}
